@@ -30,7 +30,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/manyminds/api2go/jsonapi"
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -40,6 +39,7 @@ import (
 	"go.k6.io/k6/core/local"
 	"go.k6.io/k6/js"
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/loader"
@@ -135,14 +135,20 @@ func TestSetupData(t *testing.T) {
 	}
 	logger := logrus.New()
 	logger.SetOutput(testutils.NewTestOutput(t))
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	for _, testCase := range testCases {
 		testCase := testCase
 		t.Run(testCase.name, func(t *testing.T) {
+			t.Parallel()
+
 			runner, err := js.New(
 				logger,
 				&loader.SourceData{URL: &url.URL{Path: "/script.js"}, Data: testCase.script},
 				nil,
 				lib.RuntimeOptions{},
+				builtinMetrics,
+				registry,
 			)
 			require.NoError(t, err)
 			runner.SetOptions(lib.Options{
@@ -155,7 +161,7 @@ func TestSetupData(t *testing.T) {
 			})
 			execScheduler, err := local.NewExecutionScheduler(runner, logger)
 			require.NoError(t, err)
-			engine, err := core.NewEngine(execScheduler, runner.GetOptions(), lib.RuntimeOptions{}, nil, logger)
+			engine, err := core.NewEngine(execScheduler, runner.GetOptions(), lib.RuntimeOptions{}, nil, logger, builtinMetrics)
 			require.NoError(t, err)
 
 			globalCtx, globalCancel := context.WithCancel(context.Background())
@@ -180,12 +186,13 @@ func TestSetupData(t *testing.T) {
 					return
 				}
 
-				var doc jsonapi.Document
+				var doc setUpJSONAPI
 				assert.NoError(t, json.Unmarshal(rw.Body.Bytes(), &doc))
-				require.NotNil(t, doc.Data)
-				require.NotNil(t, doc.Data.DataObject)
-				assert.Equal(t, "setupData", doc.Data.DataObject.Type)
-				assert.JSONEq(t, expResult, string(doc.Data.DataObject.Attributes))
+				assert.Equal(t, "setupData", doc.Data.Type)
+
+				encoded, err := json.Marshal(doc.Data.Attributes)
+				assert.NoError(t, err)
+				assert.JSONEq(t, expResult, string(encoded))
 			}
 
 			for _, setupRun := range testCase.setupRuns {
