@@ -68,7 +68,7 @@ func (w *consoleWriter) Write(p []byte) (n int, err error) {
 	if w.IsTTY {
 		// Add a TTY code to erase till the end of line with each new line
 		// TODO: check how cross-platform this is...
-		p = bytes.Replace(p, []byte{'\n'}, []byte{'\x1b', '[', '0', 'K', '\n'}, -1)
+		p = bytes.ReplaceAll(p, []byte{'\n'}, []byte{'\x1b', '[', '0', 'K', '\n'})
 	}
 
 	w.Mutex.Lock()
@@ -104,8 +104,8 @@ func getBanner(noColor bool) string {
 	return c.Sprint(consts.Banner())
 }
 
-func printBar(bar *pb.ProgressBar) {
-	if quiet {
+func printBar(bar *pb.ProgressBar, globalFlags *commandFlags) {
+	if globalFlags.quiet {
 		return
 	}
 	end := "\n"
@@ -113,7 +113,7 @@ func printBar(bar *pb.ProgressBar) {
 	// stateless... basically first render the left and right parts, so we know
 	// how long the longest line is, and how much space we have for the progress
 	widthDelta := -defaultTermWidth
-	if stdout.IsTTY {
+	if globalFlags.stdout.IsTTY {
 		// If we're in a TTY, instead of printing the bar and going to the next
 		// line, erase everything till the end of the line and return to the
 		// start, so that the next print will overwrite the same line.
@@ -124,24 +124,24 @@ func printBar(bar *pb.ProgressBar) {
 	}
 	rendered := bar.Render(0, widthDelta)
 	// Only output the left and middle part of the progress bar
-	fprintf(stdout, "%s%s", rendered.String(), end)
+	fprintf(globalFlags.stdout, "%s%s", rendered.String(), end)
 }
 
-func modifyAndPrintBar(bar *pb.ProgressBar, options ...pb.ProgressBarOption) {
+func modifyAndPrintBar(bar *pb.ProgressBar, globalFlags *commandFlags, options ...pb.ProgressBarOption) {
 	bar.Modify(options...)
-	printBar(bar)
+	printBar(bar, globalFlags)
 }
 
 // Print execution description for both cloud and local execution.
 // TODO: Clean this up as part of #1499 or #1427
 func printExecutionDescription(
 	execution, filename, outputOverride string, conf Config, et *lib.ExecutionTuple,
-	execPlan []lib.ExecutionStep, outputs []output.Output, noColor bool,
+	execPlan []lib.ExecutionStep, outputs []output.Output, noColor bool, globalFlags *commandFlags,
 ) {
 	valueColor := getColor(noColor, color.FgCyan)
 
-	fprintf(stdout, "  execution: %s\n", valueColor.Sprint(execution))
-	fprintf(stdout, "     script: %s\n", valueColor.Sprint(filename))
+	fprintf(globalFlags.stdout, "  execution: %s\n", valueColor.Sprint(execution))
+	fprintf(globalFlags.stdout, "     script: %s\n", valueColor.Sprint(filename))
 
 	var outputDescriptions []string
 	switch {
@@ -155,8 +155,8 @@ func printExecutionDescription(
 		}
 	}
 
-	fprintf(stdout, "     output: %s\n", valueColor.Sprint(strings.Join(outputDescriptions, ", ")))
-	fprintf(stdout, "\n")
+	fprintf(globalFlags.stdout, "     output: %s\n", valueColor.Sprint(strings.Join(outputDescriptions, ", ")))
+	fprintf(globalFlags.stdout, "\n")
 
 	maxDuration, _ := lib.GetEndOffset(execPlan)
 	executorConfigs := conf.Scenarios.GetSortedConfigs()
@@ -166,25 +166,25 @@ func printExecutionDescription(
 		scenarioDesc = fmt.Sprintf("%d scenarios", len(executorConfigs))
 	}
 
-	fprintf(stdout, "  scenarios: %s\n", valueColor.Sprintf(
+	fprintf(globalFlags.stdout, "  scenarios: %s\n", valueColor.Sprintf(
 		"(%.2f%%) %s, %d max VUs, %s max duration (incl. graceful stop):",
 		conf.ExecutionSegment.FloatLength()*100, scenarioDesc,
 		lib.GetMaxPossibleVUs(execPlan), maxDuration.Round(100*time.Millisecond)),
 	)
 	for _, ec := range executorConfigs {
-		fprintf(stdout, "           * %s: %s\n",
+		fprintf(globalFlags.stdout, "           * %s: %s\n",
 			ec.GetName(), ec.GetDescription(et))
 	}
-	fprintf(stdout, "\n")
+	fprintf(globalFlags.stdout, "\n")
 }
 
 //nolint: funlen
 func renderMultipleBars(
-	isTTY, goBack bool, maxLeft, termWidth, widthDelta int, pbs []*pb.ProgressBar,
+	isTTY, goBack bool, maxLeft, termWidth, widthDelta int, pbs []*pb.ProgressBar, globalFlags *commandFlags,
 ) (string, int) {
 	lineEnd := "\n"
 	if isTTY {
-		//TODO: check for cross platform support
+		// TODO: check for cross platform support
 		lineEnd = "\x1b[K\n" // erase till end of line
 	}
 
@@ -248,7 +248,7 @@ func renderMultipleBars(
 			longestLine = lineRuneCount
 		}
 		lineBreaks += (lineRuneCount - termPadding) / termWidth
-		if !noColor {
+		if !globalFlags.noColor {
 			rend.Color = true
 			status = fmt.Sprintf(" %s ", rend.Status())
 			line = fmt.Sprintf(leftPadFmt+"%s%s%s",
@@ -259,7 +259,7 @@ func renderMultipleBars(
 
 	if isTTY && goBack {
 		// Clear screen and go back to the beginning
-		//TODO: check for cross platform support
+		// TODO: check for cross platform support
 		result[pbsCount+1] = fmt.Sprintf("\r\x1b[J\x1b[%dA", pbsCount+lineBreaks+1)
 	} else {
 		result[pbsCount+1] = ""
@@ -268,21 +268,18 @@ func renderMultipleBars(
 	return strings.Join(result, ""), longestLine
 }
 
-//TODO: show other information here?
-//TODO: add a no-progress option that will disable these
-//TODO: don't use global variables...
-// nolint:funlen
-func showProgress(
-	ctx context.Context, conf Config,
-	pbs []*pb.ProgressBar, logger *logrus.Logger,
-) {
-	if quiet {
+// TODO: show other information here?
+// TODO: add a no-progress option that will disable these
+// TODO: don't use global variables...
+// nolint:funlen,gocognit
+func showProgress(ctx context.Context, pbs []*pb.ProgressBar, logger *logrus.Logger, globalFlags *commandFlags) {
+	if globalFlags.quiet {
 		return
 	}
 
 	var errTermGetSize bool
 	termWidth := defaultTermWidth
-	if stdoutTTY {
+	if globalFlags.stdoutTTY {
 		tw, _, err := term.GetSize(int(os.Stdout.Fd()))
 		if !(tw > 0) || err != nil {
 			errTermGetSize = true
@@ -307,14 +304,15 @@ func showProgress(
 
 	printProgressBars := func() {
 		progressBarsLastRenderLock.Lock()
-		_, _ = stdout.Writer.Write(progressBarsLastRender)
+		_, _ = globalFlags.stdout.Writer.Write(progressBarsLastRender)
 		progressBarsLastRenderLock.Unlock()
 	}
 
 	var widthDelta int
 	// Default to responsive progress bars when in an interactive terminal
 	renderProgressBars := func(goBack bool) {
-		barText, longestLine := renderMultipleBars(stdoutTTY, goBack, maxLeft, termWidth, widthDelta, pbs)
+		barText, longestLine := renderMultipleBars(
+			globalFlags.stdoutTTY, goBack, maxLeft, termWidth, widthDelta, pbs, globalFlags)
 		widthDelta = termWidth - longestLine - termPadding
 		progressBarsLastRenderLock.Lock()
 		progressBarsLastRender = []byte(barText)
@@ -322,29 +320,29 @@ func showProgress(
 	}
 
 	// Otherwise fallback to fixed compact progress bars
-	if !stdoutTTY {
+	if !globalFlags.stdoutTTY {
 		widthDelta = -pb.DefaultWidth
 		renderProgressBars = func(goBack bool) {
-			barText, _ := renderMultipleBars(stdoutTTY, goBack, maxLeft, termWidth, widthDelta, pbs)
+			barText, _ := renderMultipleBars(globalFlags.stdoutTTY, goBack, maxLeft, termWidth, widthDelta, pbs, globalFlags)
 			progressBarsLastRenderLock.Lock()
 			progressBarsLastRender = []byte(barText)
 			progressBarsLastRenderLock.Unlock()
 		}
 	}
 
-	//TODO: make configurable?
+	// TODO: make configurable?
 	updateFreq := 1 * time.Second
-	if stdoutTTY {
+	if globalFlags.stdoutTTY {
 		updateFreq = 100 * time.Millisecond
-		outMutex.Lock()
-		stdout.PersistentText = printProgressBars
-		stderr.PersistentText = printProgressBars
-		outMutex.Unlock()
+		globalFlags.outMutex.Lock()
+		globalFlags.stdout.PersistentText = printProgressBars
+		globalFlags.stderr.PersistentText = printProgressBars
+		globalFlags.outMutex.Unlock()
 		defer func() {
-			outMutex.Lock()
-			stdout.PersistentText = nil
-			stderr.PersistentText = nil
-			outMutex.Unlock()
+			globalFlags.outMutex.Lock()
+			globalFlags.stdout.PersistentText = nil
+			globalFlags.stderr.PersistentText = nil
+			globalFlags.outMutex.Unlock()
 		}()
 	}
 
@@ -364,12 +362,12 @@ func showProgress(
 		select {
 		case <-ctxDone:
 			renderProgressBars(false)
-			outMutex.Lock()
+			globalFlags.outMutex.Lock()
 			printProgressBars()
-			outMutex.Unlock()
+			globalFlags.outMutex.Unlock()
 			return
 		case <-winch:
-			if stdoutTTY && !errTermGetSize {
+			if globalFlags.stdoutTTY && !errTermGetSize {
 				// More responsive progress bar resizing on platforms with SIGWINCH (*nix)
 				tw, _, err := term.GetSize(fd)
 				if tw > 0 && err == nil {
@@ -378,7 +376,7 @@ func showProgress(
 			}
 		case <-ticker.C:
 			// Default ticker-based progress bar resizing
-			if stdoutTTY && !errTermGetSize && winch == nil {
+			if globalFlags.stdoutTTY && !errTermGetSize && winch == nil {
 				tw, _, err := term.GetSize(fd)
 				if tw > 0 && err == nil {
 					termWidth = tw
@@ -386,9 +384,9 @@ func showProgress(
 			}
 		}
 		renderProgressBars(true)
-		outMutex.Lock()
+		globalFlags.outMutex.Lock()
 		printProgressBars()
-		outMutex.Unlock()
+		globalFlags.outMutex.Unlock()
 	}
 }
 
