@@ -252,22 +252,21 @@ func (b *Bundle) getExports(logger logrus.FieldLogger, rt *goja.Runtime, options
 }
 
 // Instantiate creates a new runtime from this bundle.
-func (b *Bundle) Instantiate(logger logrus.FieldLogger, vuID uint64) (bi *BundleInstance, instErr error) {
-	// TODO: actually use a real context here, so that the instantiation can be killed
-	// Placeholder for a real context.
-	ctxPtr := new(context.Context)
-
+func (b *Bundle) Instantiate(
+	logger logrus.FieldLogger, vuID uint64, vuImpl *moduleVUImpl,
+) (bi *BundleInstance, instErr error) {
 	// Instantiate the bundle into a new VM using a bound init context. This uses a context with a
 	// runtime, but no state, to allow module-provided types to function within the init context.
-	rt := goja.New()
-	init := newBoundInitContext(b.BaseInitContext, ctxPtr, rt)
-	if err := b.instantiate(logger, rt, init, vuID); err != nil {
+	vuImpl.runtime = goja.New()
+	init := newBoundInitContext(b.BaseInitContext, vuImpl)
+	if err := b.instantiate(logger, vuImpl.runtime, init, vuID); err != nil {
 		return nil, err
 	}
 
+	rt := vuImpl.runtime
 	bi = &BundleInstance{
 		Runtime: rt,
-		Context: ctxPtr,
+		Context: vuImpl.ctxPtr,
 		exports: make(map[string]goja.Callable),
 		env:     b.RuntimeOptions.Env,
 	}
@@ -315,7 +314,7 @@ func (b *Bundle) instantiate(logger logrus.FieldLogger, rt *goja.Runtime, init *
 	}
 	rt.Set("__ENV", env)
 	rt.Set("__VU", vuID)
-	rt.Set("console", common.Bind(rt, newConsole(logger), init.ctxPtr))
+	_ = rt.Set("console", newConsole(logger))
 
 	if init.compatibilityMode == lib.CompatibilityModeExtended {
 		rt.Set("global", rt.GlobalObject())
@@ -329,10 +328,19 @@ func (b *Bundle) instantiate(logger logrus.FieldLogger, rt *goja.Runtime, init *
 		CWD:         init.pwd,
 		Registry:    b.registry,
 	}
+	init.moduleVUImpl.initEnv = initenv
 	ctx := common.WithInitEnv(context.Background(), initenv)
-	*init.ctxPtr = common.WithRuntime(ctx, rt)
-	unbindInit := common.BindToGlobal(rt, common.Bind(rt, init, init.ctxPtr))
-	if _, err := rt.RunProgram(b.Program); err != nil {
+	*init.moduleVUImpl.ctxPtr = common.WithRuntime(ctx, rt)
+	unbindInit := common.BindToGlobal(rt, map[string]interface{}{
+		"require": init.Require,
+		"open":    init.Open,
+	})
+	init.moduleVUImpl.eventLoop = newEventLoop(init.moduleVUImpl)
+	err := init.moduleVUImpl.eventLoop.start(func() error {
+		_, err := rt.RunProgram(b.Program)
+		return err
+	})
+	if err != nil {
 		var exception *goja.Exception
 		if errors.As(err, &exception) {
 			err = &scriptException{inner: exception}
@@ -340,7 +348,8 @@ func (b *Bundle) instantiate(logger logrus.FieldLogger, rt *goja.Runtime, init *
 		return err
 	}
 	unbindInit()
-	*init.ctxPtr = nil
+	*init.moduleVUImpl.ctxPtr = nil
+	init.moduleVUImpl.initEnv = nil
 
 	// If we've already initialized the original VU init context, forbid
 	// any subsequent VUs to open new files
