@@ -21,28 +21,22 @@
 package http
 
 import (
-	"context"
 	"fmt"
 	"sort"
 	"testing"
 
 	"github.com/dop251/goja"
-	"go.k6.io/k6/js/common"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/stats"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 func TestExpectedStatuses(t *testing.T) {
 	t.Parallel()
-	rt := goja.New()
-	rt.SetFieldNameMapper(common.FieldNameMapper{})
-	ctx := context.Background()
+	rt, _ := getTestModuleInstance(t, nil, nil)
 
-	ctx = common.WithRuntime(ctx, rt)
-	rt.Set("http", common.Bind(rt, new(GlobalHTTP).NewModuleInstancePerVU(), &ctx))
 	cases := map[string]struct {
 		code, err string
 		expected  expectedStatuses
@@ -103,28 +97,26 @@ func TestExpectedStatuses(t *testing.T) {
 
 type expectedSample struct {
 	tags    map[string]string
-	metrics []*stats.Metric
+	metrics []string
 }
 
 func TestResponseCallbackInAction(t *testing.T) {
 	t.Parallel()
-	tb, _, samples, rt, ctx := newRuntime(t)
+	tb, _, samples, rt, mii := newRuntime(t)
 	sr := tb.Replacer.Replace
-	httpModule := new(GlobalHTTP).NewModuleInstancePerVU().(*HTTP)
-	rt.Set("http", common.Bind(rt, httpModule, ctx))
 
-	HTTPMetricsWithoutFailed := []*stats.Metric{
-		metrics.HTTPReqs,
-		metrics.HTTPReqBlocked,
-		metrics.HTTPReqConnecting,
-		metrics.HTTPReqDuration,
-		metrics.HTTPReqReceiving,
-		metrics.HTTPReqWaiting,
-		metrics.HTTPReqSending,
-		metrics.HTTPReqTLSHandshaking,
+	HTTPMetricsWithoutFailed := []string{
+		metrics.HTTPReqsName,
+		metrics.HTTPReqBlockedName,
+		metrics.HTTPReqConnectingName,
+		metrics.HTTPReqDurationName,
+		metrics.HTTPReqReceivingName,
+		metrics.HTTPReqWaitingName,
+		metrics.HTTPReqSendingName,
+		metrics.HTTPReqTLSHandshakingName,
 	}
 
-	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailed)
+	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName)
 
 	testCases := map[string]struct {
 		code            string
@@ -282,7 +274,7 @@ func TestResponseCallbackInAction(t *testing.T) {
 	for name, testCase := range testCases {
 		testCase := testCase
 		t.Run(name, func(t *testing.T) {
-			httpModule.responseCallback = defaultExpectedStatuses.match
+			mii.defaultClient.responseCallback = defaultExpectedStatuses.match
 
 			_, err := rt.RunString(sr(testCase.code))
 			assert.NoError(t, err)
@@ -308,23 +300,21 @@ func TestResponseCallbackInAction(t *testing.T) {
 
 func TestResponseCallbackBatch(t *testing.T) {
 	t.Parallel()
-	tb, _, samples, rt, ctx := newRuntime(t)
+	tb, _, samples, rt, mii := newRuntime(t)
 	sr := tb.Replacer.Replace
-	httpModule := new(GlobalHTTP).NewModuleInstancePerVU().(*HTTP)
-	rt.Set("http", common.Bind(rt, httpModule, ctx))
 
-	HTTPMetricsWithoutFailed := []*stats.Metric{
-		metrics.HTTPReqs,
-		metrics.HTTPReqBlocked,
-		metrics.HTTPReqConnecting,
-		metrics.HTTPReqDuration,
-		metrics.HTTPReqReceiving,
-		metrics.HTTPReqWaiting,
-		metrics.HTTPReqSending,
-		metrics.HTTPReqTLSHandshaking,
+	HTTPMetricsWithoutFailed := []string{
+		metrics.HTTPReqsName,
+		metrics.HTTPReqBlockedName,
+		metrics.HTTPReqConnectingName,
+		metrics.HTTPReqDurationName,
+		metrics.HTTPReqReceivingName,
+		metrics.HTTPReqWaitingName,
+		metrics.HTTPReqSendingName,
+		metrics.HTTPReqTLSHandshakingName,
 	}
 
-	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailed)
+	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName)
 	// IMPORTANT: the tests here depend on the fact that the url they hit can be ordered in the same
 	// order as the expectedSamples even if they are made concurrently
 	testCases := map[string]struct {
@@ -393,7 +383,7 @@ func TestResponseCallbackBatch(t *testing.T) {
 	for name, testCase := range testCases {
 		testCase := testCase
 		t.Run(name, func(t *testing.T) {
-			httpModule.responseCallback = defaultExpectedStatuses.match
+			mii.defaultClient.responseCallback = defaultExpectedStatuses.match
 
 			_, err := rt.RunString(sr(testCase.code))
 			assert.NoError(t, err)
@@ -424,22 +414,20 @@ func TestResponseCallbackBatch(t *testing.T) {
 
 func TestResponseCallbackInActionWithoutPassedTag(t *testing.T) {
 	t.Parallel()
-	tb, state, samples, rt, ctx := newRuntime(t)
+	tb, state, samples, rt, _ := newRuntime(t)
 	sr := tb.Replacer.Replace
-	allHTTPMetrics := []*stats.Metric{
-		metrics.HTTPReqs,
-		metrics.HTTPReqFailed,
-		metrics.HTTPReqBlocked,
-		metrics.HTTPReqConnecting,
-		metrics.HTTPReqDuration,
-		metrics.HTTPReqReceiving,
-		metrics.HTTPReqSending,
-		metrics.HTTPReqWaiting,
-		metrics.HTTPReqTLSHandshaking,
+	allHTTPMetrics := []string{
+		metrics.HTTPReqsName,
+		metrics.HTTPReqFailedName,
+		metrics.HTTPReqBlockedName,
+		metrics.HTTPReqConnectingName,
+		metrics.HTTPReqDurationName,
+		metrics.HTTPReqReceivingName,
+		metrics.HTTPReqSendingName,
+		metrics.HTTPReqWaitingName,
+		metrics.HTTPReqTLSHandshakingName,
 	}
 	deleteSystemTag(state, stats.TagExpectedResponse.String())
-	httpModule := new(GlobalHTTP).NewModuleInstancePerVU().(*HTTP)
-	rt.Set("http", common.Bind(rt, httpModule, ctx))
 
 	_, err := rt.RunString(sr(`http.request("GET", "HTTPBIN_URL/redirect/1", null, {responseCallback: http.expectedStatuses(200)});`))
 	assert.NoError(t, err)
@@ -465,7 +453,7 @@ func TestResponseCallbackInActionWithoutPassedTag(t *testing.T) {
 		"proto":  "HTTP/1.1",
 	}
 	assertRequestMetricsEmittedSingle(t, bufSamples[0], tags, allHTTPMetrics, func(sample stats.Sample) {
-		if sample.Metric.Name == metrics.HTTPReqFailed.Name {
+		if sample.Metric.Name == metrics.HTTPReqFailedName {
 			require.EqualValues(t, sample.Value, 1)
 		}
 	})
@@ -473,7 +461,7 @@ func TestResponseCallbackInActionWithoutPassedTag(t *testing.T) {
 	tags["name"] = tags["url"]
 	tags["status"] = "200"
 	assertRequestMetricsEmittedSingle(t, bufSamples[1], tags, allHTTPMetrics, func(sample stats.Sample) {
-		if sample.Metric.Name == metrics.HTTPReqFailed.Name {
+		if sample.Metric.Name == metrics.HTTPReqFailedName {
 			require.EqualValues(t, sample.Value, 0)
 		}
 	})
@@ -481,25 +469,22 @@ func TestResponseCallbackInActionWithoutPassedTag(t *testing.T) {
 
 func TestDigestWithResponseCallback(t *testing.T) {
 	t.Parallel()
-	tb, _, samples, rt, ctx := newRuntime(t)
-
-	httpModule := new(GlobalHTTP).NewModuleInstancePerVU().(*HTTP)
-	rt.Set("http", common.Bind(rt, httpModule, ctx))
+	tb, _, samples, rt, _ := newRuntime(t)
 
 	urlWithCreds := tb.Replacer.Replace(
 		"http://testuser:testpwd@HTTPBIN_IP:HTTPBIN_PORT/digest-auth/auth/testuser/testpwd",
 	)
 
-	allHTTPMetrics := []*stats.Metric{
-		metrics.HTTPReqs,
-		metrics.HTTPReqFailed,
-		metrics.HTTPReqBlocked,
-		metrics.HTTPReqConnecting,
-		metrics.HTTPReqDuration,
-		metrics.HTTPReqReceiving,
-		metrics.HTTPReqSending,
-		metrics.HTTPReqWaiting,
-		metrics.HTTPReqTLSHandshaking,
+	allHTTPMetrics := []string{
+		metrics.HTTPReqsName,
+		metrics.HTTPReqFailedName,
+		metrics.HTTPReqBlockedName,
+		metrics.HTTPReqConnectingName,
+		metrics.HTTPReqDurationName,
+		metrics.HTTPReqReceivingName,
+		metrics.HTTPReqSendingName,
+		metrics.HTTPReqWaitingName,
+		metrics.HTTPReqTLSHandshakingName,
 	}
 	_, err := rt.RunString(fmt.Sprintf(`
 		var res = http.get(%q,  { auth: "digest" });
@@ -534,14 +519,14 @@ func TestDigestWithResponseCallback(t *testing.T) {
 		"error_code":        "1401",
 	}
 	assertRequestMetricsEmittedSingle(t, bufSamples[0], tags, allHTTPMetrics, func(sample stats.Sample) {
-		if sample.Metric.Name == metrics.HTTPReqFailed.Name {
+		if sample.Metric.Name == metrics.HTTPReqFailedName {
 			require.EqualValues(t, sample.Value, 0)
 		}
 	})
 	tags["status"] = "200"
 	delete(tags, "error_code")
 	assertRequestMetricsEmittedSingle(t, bufSamples[1], tags, allHTTPMetrics, func(sample stats.Sample) {
-		if sample.Metric.Name == metrics.HTTPReqFailed.Name {
+		if sample.Metric.Name == metrics.HTTPReqFailedName {
 			require.EqualValues(t, sample.Value, 0)
 		}
 	})
