@@ -49,6 +49,7 @@ var (
 		"IsHTMLDDA",                   // not supported at all
 		"generators",                  // not supported in a meaningful way IMO
 		"Array.prototype.item",        // not even standard yet
+		"async-iteration",             // not supported at all
 		"TypedArray.prototype.item",   // not even standard yet
 		"String.prototype.replaceAll", // not supported at all, Stage 4 since 2020
 
@@ -71,7 +72,6 @@ var (
 		"logical-assignment-operators",
 		"coalesce-expression",
 		"import.meta",
-		"optional-chaining",
 		"Atomics",
 		"Atomics.waitAsync",
 		"FinalizationRegistry",
@@ -91,7 +91,7 @@ var (
 		"String.prototype.at",     // stage 3 as of 2021 https://github.com/tc39/proposal-relative-indexing-method
 		"TypedArray.prototype.at", // stage 3 as of 2021 https://github.com/tc39/proposal-relative-indexing-method
 	}
-	skipWords = []string{"async", "yield", "generator", "Generator"}
+	skipWords = []string{"yield", "generator", "Generator"}
 	skipList  = map[string]bool{
 		"test/built-ins/Function/prototype/toString/AsyncFunction.js": true,
 		"test/built-ins/Object/seal/seal-generatorfunction.js":        true,
@@ -134,10 +134,12 @@ var (
 		"test/built-ins/BigInt",
 		"test/built-ins/SharedArrayBuffer",
 		"test/language/eval-code/direct/async",
+		"test/language/expressions/await",
 		"test/language/expressions/async",
 		"test/language/expressions/dynamic-import",
 		"test/language/expressions/object/dstr/async",
 		"test/language/module-code/top-level-await",
+		"test/language/statements/async-function",
 		"test/built-ins/Function/prototype/toString/async",
 		"test/built-ins/Function/prototype/toString/async",
 		"test/built-ins/Function/prototype/toString/generator",
@@ -303,6 +305,20 @@ func (ctx *tc39TestCtx) runTC39Test(t testing.TB, name, src string, meta *tc39Me
 	if strict {
 		src = "'use strict';\n" + src
 	}
+
+	var out []string
+	async := meta.hasFlag("async") //nolint:ifshort // false positive
+	if async {
+		err = ctx.runFile(ctx.base, path.Join("harness", "doneprintHandle.js"), vm)
+		if err != nil {
+			t.Fatal(err)
+		}
+		_ = vm.Set("print", func(msg string) {
+			out = append(out, msg)
+		})
+	} else {
+		_ = vm.Set("print", t.Log)
+	}
 	early, origErr, err := ctx.runTC39Script(name, src, meta.Includes, vm)
 
 	if err == nil {
@@ -350,6 +366,22 @@ func (ctx *tc39TestCtx) runTC39Test(t testing.TB, name, src string, meta *tc39Me
 			t.Fatalf("iter stack is not empty: %d", l)
 		}
 	*/
+	if async {
+		complete := false
+		for _, line := range out {
+			if strings.HasPrefix(line, "Test262:AsyncTestFailure:") {
+				t.Fatal(line)
+			} else if line == "Test262:AsyncTestComplete" {
+				complete = true
+			}
+		}
+		if !complete {
+			for _, line := range out {
+				t.Log(line)
+			}
+			t.Fatal("Test262:AsyncTestComplete was not printed")
+		}
+	}
 }
 
 func getErrType(name string, err error, failf func(str string, args ...interface{})) string {
@@ -382,10 +414,6 @@ func getErrType(name string, err error, failf func(str string, args ...interface
 }
 
 func shouldBeSkipped(t testing.TB, meta *tc39Meta) {
-	if meta.hasFlag("async") { // this is totally not supported
-		t.Skipf("Skipping as it has flag async")
-	}
-
 	for _, feature := range meta.Features {
 		for _, bl := range featuresBlockList {
 			if feature == bl {
