@@ -74,7 +74,7 @@ func TestConstantArrivalRateRunNotEnoughAllocatedVUsWarn(t *testing.T) {
 	es := lib.NewExecutionState(lib.Options{}, et, 10, 50)
 	ctx, cancel, executor, logHook := setupExecutor(
 		t, getTestConstantArrivalRateConfig(), es,
-		simpleRunner(func(ctx context.Context) error {
+		simpleRunner(func(ctx context.Context, _ *lib.State) error {
 			time.Sleep(time.Second)
 			return nil
 		}),
@@ -104,7 +104,7 @@ func TestConstantArrivalRateRunCorrectRate(t *testing.T) {
 	es := lib.NewExecutionState(lib.Options{}, et, 10, 50)
 	ctx, cancel, executor, logHook := setupExecutor(
 		t, getTestConstantArrivalRateConfig(), es,
-		simpleRunner(func(ctx context.Context) error {
+		simpleRunner(func(ctx context.Context, _ *lib.State) error {
 			atomic.AddInt64(&count, 1)
 			return nil
 		}),
@@ -211,7 +211,7 @@ func TestConstantArrivalRateRunCorrectTiming(t *testing.T) {
 			expectedTimeInt64 := int64(test.start)
 			ctx, cancel, executor, logHook := setupExecutor(
 				t, config, es,
-				simpleRunner(func(ctx context.Context) error {
+				simpleRunner(func(ctx context.Context, _ *lib.State) error {
 					current := atomic.AddInt64(&count, 1)
 
 					expectedTime := test.start
@@ -219,10 +219,13 @@ func TestConstantArrivalRateRunCorrectTiming(t *testing.T) {
 						expectedTime = time.Duration(atomic.AddInt64(&expectedTimeInt64,
 							int64(time.Millisecond)*test.steps[(current-2)%int64(len(test.steps))]))
 					}
+
+					// FIXME: replace this check with a unit test asserting that the scheduling is correct,
+					// without depending on the execution time itself
 					assert.WithinDuration(t,
 						startTime.Add(expectedTime),
 						time.Now(),
-						time.Millisecond*12,
+						time.Millisecond*24,
 						"%d expectedTime %s", current, expectedTime,
 					)
 
@@ -274,7 +277,7 @@ func TestArrivalRateCancel(t *testing.T) {
 			require.NoError(t, err)
 			es := lib.NewExecutionState(lib.Options{}, et, 10, 50)
 			ctx, cancel, executor, logHook := setupExecutor(
-				t, config, es, simpleRunner(func(ctx context.Context) error {
+				t, config, es, simpleRunner(func(ctx context.Context, _ *lib.State) error {
 					select {
 					case <-ch:
 						<-ch
@@ -329,7 +332,7 @@ func TestConstantArrivalRateDroppedIterations(t *testing.T) {
 	es := lib.NewExecutionState(lib.Options{}, et, 10, 50)
 	ctx, cancel, executor, logHook := setupExecutor(
 		t, config, es,
-		simpleRunner(func(ctx context.Context) error {
+		simpleRunner(func(ctx context.Context, _ *lib.State) error {
 			atomic.AddInt64(&count, 1)
 			<-ctx.Done()
 			return nil
@@ -389,8 +392,7 @@ func TestConstantArrivalRateGlobalIters(t *testing.T) {
 
 			gotIters := []uint64{}
 			var mx sync.Mutex
-			runner.Fn = func(ctx context.Context, _ chan<- stats.SampleContainer) error {
-				state := lib.GetState(ctx)
+			runner.Fn = func(ctx context.Context, state *lib.State, _ chan<- stats.SampleContainer) error {
 				mx.Lock()
 				gotIters = append(gotIters, state.GetScenarioGlobalVUIter())
 				mx.Unlock()
