@@ -33,6 +33,7 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/stats"
 	"go.k6.io/k6/ui/pb"
@@ -80,7 +81,7 @@ func (mecc ExternallyControlledConfigParams) Validate() (errors []error) {
 
 	if !mecc.Duration.Valid {
 		errors = append(errors, fmt.Errorf("the duration should be specified, for infinite duration use 0"))
-	} else if time.Duration(mecc.Duration.Duration) < 0 {
+	} else if mecc.Duration.TimeDuration() < 0 {
 		errors = append(errors, fmt.Errorf(
 			"the duration shouldn't be negative, for infinite duration use 0",
 		))
@@ -147,7 +148,7 @@ func (mec ExternallyControlledConfig) GetExecutionRequirements(et *lib.Execution
 		MaxUnplannedVUs: 0,                                          // intentional, see function comment
 	}
 
-	maxDuration := time.Duration(mec.Duration.Duration)
+	maxDuration := mec.Duration.TimeDuration()
 	if maxDuration == 0 {
 		// Infinite duration, don't emit 0 VUs at the end since there's no planned end
 		return []lib.ExecutionStep{startVUs}
@@ -318,7 +319,7 @@ func (mex *ExternallyControlled) stopWhenDurationIsReached(ctx context.Context,
 		// TODO: something saner and more optimized that sleeps for pauses and
 		// doesn't depend on the global execution state?
 		case <-checkInterval.C:
-			elapsed := mex.executionState.GetCurrentTestRunDuration() - time.Duration(mex.config.StartTime.Duration)
+			elapsed := mex.executionState.GetCurrentTestRunDuration() - mex.config.StartTime.TimeDuration()
 			if elapsed >= duration {
 				cancel()
 				return
@@ -414,8 +415,7 @@ func (rs *externallyControlledRunState) progressFn() (float64, []string) {
 
 	// TODO: use a saner way to calculate the elapsed time, without relying on
 	// the global execution state...
-	elapsed := rs.executor.executionState.GetCurrentTestRunDuration() - time.Duration(
-		rs.executor.config.StartTime.Duration)
+	elapsed := rs.executor.executionState.GetCurrentTestRunDuration() - rs.executor.config.StartTime.TimeDuration()
 	if elapsed > rs.duration {
 		return 1, right
 	}
@@ -499,8 +499,10 @@ func (rs *externallyControlledRunState) handleConfigChange(oldCfg, newCfg Extern
 // Run constantly loops through as many iterations as possible on a variable
 // dynamically controlled number of VUs either for the specified duration, or
 // until the test is manually stopped.
-// nolint:funlen,gocognit
-func (mex *ExternallyControlled) Run(parentCtx context.Context, out chan<- stats.SampleContainer) (err error) {
+// nolint:funlen,gocognit,cyclop
+func (mex *ExternallyControlled) Run(
+	parentCtx context.Context, out chan<- stats.SampleContainer, _ *metrics.BuiltinMetrics,
+) (err error) {
 	mex.configLock.RLock()
 	// Safely get the current config - it's important that the close of the
 	// hasStarted channel is inside of the lock, so that there are no data races
@@ -512,7 +514,7 @@ func (mex *ExternallyControlled) Run(parentCtx context.Context, out chan<- stats
 	ctx, cancel := context.WithCancel(parentCtx)
 	defer cancel()
 
-	duration := time.Duration(currentControlConfig.Duration.Duration)
+	duration := currentControlConfig.Duration.TimeDuration()
 	if duration > 0 { // Only keep track of duration if it's not infinite
 		go mex.stopWhenDurationIsReached(ctx, duration, cancel)
 	}
