@@ -99,7 +99,7 @@ func (pvic PerVUIterationsConfig) Validate() []error {
 		errors = append(errors, fmt.Errorf("the number of iterations should be more than 0"))
 	}
 
-	if time.Duration(pvic.MaxDuration.Duration) < minDuration {
+	if pvic.MaxDuration.TimeDuration() < minDuration {
 		errors = append(errors, fmt.Errorf(
 			"the maxDuration should be at least %s, but is %s", minDuration, pvic.MaxDuration,
 		))
@@ -120,7 +120,7 @@ func (pvic PerVUIterationsConfig) GetExecutionRequirements(et *lib.ExecutionTupl
 			PlannedVUs: uint64(pvic.GetVUs(et)),
 		},
 		{
-			TimeOffset: time.Duration(pvic.MaxDuration.Duration + pvic.GracefulStop.Duration),
+			TimeOffset: pvic.MaxDuration.TimeDuration() + pvic.GracefulStop.TimeDuration(),
 			PlannedVUs: 0,
 		},
 	}
@@ -152,10 +152,12 @@ var _ lib.Executor = &PerVUIterations{}
 
 // Run executes a specific number of iterations with each configured VU.
 // nolint:funlen
-func (pvi PerVUIterations) Run(parentCtx context.Context, out chan<- stats.SampleContainer) (err error) {
+func (pvi PerVUIterations) Run(
+	parentCtx context.Context, out chan<- stats.SampleContainer, builtinMetrics *metrics.BuiltinMetrics,
+) (err error) {
 	numVUs := pvi.config.GetVUs(pvi.executionState.ExecutionTuple)
 	iterations := pvi.config.GetIterations()
-	duration := time.Duration(pvi.config.MaxDuration.Duration)
+	duration := pvi.config.MaxDuration.TimeDuration()
 	gracefulStop := pvi.config.GetGracefulStop()
 
 	startTime, maxDurationCtx, regDurationCtx, cancel := getDurationContexts(parentCtx, duration, gracefulStop)
@@ -212,6 +214,7 @@ func (pvi PerVUIterations) Run(parentCtx context.Context, out chan<- stats.Sampl
 		activeVUs.Done()
 	}
 
+	droppedIterationMetric := builtinMetrics.DroppedIterations
 	handleVU := func(initVU lib.InitializedVU) {
 		defer handleVUsWG.Done()
 		ctx, cancel := context.WithCancel(maxDurationCtx)
@@ -226,7 +229,7 @@ func (pvi PerVUIterations) Run(parentCtx context.Context, out chan<- stats.Sampl
 			select {
 			case <-regDurationDone:
 				stats.PushIfNotDone(parentCtx, out, stats.Sample{
-					Value: float64(iterations - i), Metric: metrics.DroppedIterations,
+					Value: float64(iterations - i), Metric: droppedIterationMetric,
 					Tags: pvi.getMetricTags(&vuID), Time: time.Now(),
 				})
 				return // don't make more iterations
