@@ -31,6 +31,7 @@ import (
 
 	"github.com/sirupsen/logrus"
 
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/stats"
 	"go.k6.io/k6/ui/pb"
 )
@@ -128,7 +129,7 @@ type Executor interface {
 	GetLogger() *logrus.Entry
 
 	Init(ctx context.Context) error
-	Run(ctx context.Context, engineOut chan<- stats.SampleContainer) error
+	Run(ctx context.Context, engineOut chan<- stats.SampleContainer, builtinMetrics *metrics.BuiltinMetrics) error
 }
 
 // PausableExecutor should be implemented by the executors that can be paused
