@@ -30,6 +30,7 @@ import (
 	"net/http"
 	"net/http/httptest"
 	"net/url"
+	"os"
 	"sort"
 	"strconv"
 	"sync"
@@ -178,6 +179,7 @@ func runCloudOutputTestCase(t *testing.T, minSamples int) {
 		require.NoError(t, err)
 	}))
 
+	builtinMetrics := metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
 	out, err := newOutput(output.Params{
 		Logger:     testutils.NewLogger(t),
 		JSONConfig: json.RawMessage(fmt.Sprintf(`{"host": "%s", "noCompress": true}`, tb.ServerHTTP.URL)),
@@ -222,15 +224,15 @@ func runCloudOutputTestCase(t *testing.T, minSamples int) {
 
 	out.AddMetricSamples([]stats.SampleContainer{stats.Sample{
 		Time:   now,
-		Metric: metrics.VUs,
+		Metric: builtinMetrics.VUs,
 		Tags:   tags,
 		Value:  1.0,
 	}})
 	expSamples <- []Sample{{
 		Type:   DataTypeSingle,
-		Metric: metrics.VUs.Name,
+		Metric: metrics.VUsName,
 		Data: &SampleDataSingle{
-			Type:  metrics.VUs.Type,
+			Type:  builtinMetrics.VUs.Type,
 			Time:  toMicroSecond(now),
 			Tags:  tags,
 			Value: 1.0,
@@ -305,6 +307,7 @@ func runCloudOutputTestCase(t *testing.T, minSamples int) {
 
 func TestCloudOutputMaxPerPacket(t *testing.T) {
 	t.Parallel()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
 	tb := httpmultibin.NewHTTPMultiBin(t)
 	maxMetricSamplesPerPackage := 20
 	tb.Mux.HandleFunc("/v1/tests", http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
@@ -356,7 +359,7 @@ func TestCloudOutputMaxPerPacket(t *testing.T) {
 
 	out.AddMetricSamples([]stats.SampleContainer{stats.Sample{
 		Time:   now,
-		Metric: metrics.VUs,
+		Metric: builtinMetrics.VUs,
 		Tags:   stats.NewSampleTags(tags.CloneTags()),
 		Value:  1.0,
 	}})
@@ -399,6 +402,7 @@ func TestCloudOutputStopSendingMetric(t *testing.T) {
 
 func testCloudOutputStopSendingMetric(t *testing.T, stopOnError bool) {
 	tb := httpmultibin.NewHTTPMultiBin(t)
+	builtinMetrics := metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
 	tb.Mux.HandleFunc("/v1/tests", http.HandlerFunc(func(resp http.ResponseWriter, req *http.Request) {
 		body, err := ioutil.ReadAll(req.Body)
 		require.NoError(t, err)
@@ -480,7 +484,7 @@ func testCloudOutputStopSendingMetric(t *testing.T, stopOnError bool) {
 
 	out.AddMetricSamples([]stats.SampleContainer{stats.Sample{
 		Time:   now,
-		Metric: metrics.VUs,
+		Metric: builtinMetrics.VUs,
 		Tags:   stats.NewSampleTags(tags.CloneTags()),
 		Value:  1.0,
 	}})
@@ -520,7 +524,7 @@ func testCloudOutputStopSendingMetric(t *testing.T, stopOnError bool) {
 	nBufferHTTPTrails := len(out.bufferHTTPTrails)
 	out.AddMetricSamples([]stats.SampleContainer{stats.Sample{
 		Time:   now,
-		Metric: metrics.VUs,
+		Metric: builtinMetrics.VUs,
 		Tags:   stats.NewSampleTags(tags.CloneTags()),
 		Value:  1.0,
 	}})
@@ -601,6 +605,7 @@ func TestCloudOutputAggregationPeriodZeroNoBlock(t *testing.T) {
 
 func TestCloudOutputPushRefID(t *testing.T) {
 	t.Parallel()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
 	expSamples := make(chan []Sample)
 	defer close(expSamples)
 
@@ -637,15 +642,15 @@ func TestCloudOutputPushRefID(t *testing.T) {
 
 	out.AddMetricSamples([]stats.SampleContainer{stats.Sample{
 		Time:   now,
-		Metric: metrics.HTTPReqDuration,
+		Metric: builtinMetrics.HTTPReqDuration,
 		Tags:   tags,
 		Value:  123.45,
 	}})
 	exp := []Sample{{
 		Type:   DataTypeSingle,
-		Metric: metrics.HTTPReqDuration.Name,
+		Metric: metrics.HTTPReqDurationName,
 		Data: &SampleDataSingle{
-			Type:  metrics.HTTPReqDuration.Type,
+			Type:  builtinMetrics.HTTPReqDuration.Type,
 			Time:  toMicroSecond(now),
 			Tags:  tags,
 			Value: 123.45,
@@ -663,6 +668,7 @@ func TestCloudOutputPushRefID(t *testing.T) {
 
 func TestCloudOutputRecvIterLIAllIterations(t *testing.T) {
 	t.Parallel()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
 	tb := httpmultibin.NewHTTPMultiBin(t)
 	tb.Mux.HandleFunc("/v1/tests", http.HandlerFunc(func(resp http.ResponseWriter, req *http.Request) {
 		body, err := ioutil.ReadAll(req.Body)
@@ -732,17 +738,17 @@ func TestCloudOutputRecvIterLIAllIterations(t *testing.T) {
 		Samples: []stats.Sample{
 			{
 				Time:   now,
-				Metric: metrics.DataSent,
+				Metric: builtinMetrics.DataSent,
 				Value:  float64(200),
 			},
 			{
 				Time:   now,
-				Metric: metrics.DataReceived,
+				Metric: builtinMetrics.DataReceived,
 				Value:  float64(100),
 			},
 			{
 				Time:   now,
-				Metric: metrics.Iterations,
+				Metric: builtinMetrics.Iterations,
 				Value:  1,
 			},
 		},
@@ -853,3 +859,25 @@ func TestPublishMetric(t *testing.T) {
 
 	assert.Nil(t, err)
 }
+
+func TestNewOutputClientTimeout(t *testing.T) {
+	t.Parallel()
+	ts := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, r *http.Request) {
+		time.Sleep(5 * time.Millisecond)
+	}))
+	defer ts.Close()
+
+	out, err := newOutput(output.Params{
+		Logger:     testutils.NewLogger(t),
+		JSONConfig: json.RawMessage(fmt.Sprintf(`{"host": "%s",  "timeout": "2ms"}`, ts.URL)),
+		ScriptOptions: lib.Options{
+			Duration:   types.NullDurationFrom(1 * time.Second),
+			SystemTags: &stats.DefaultSystemTagSet,
+		},
+		ScriptPath: &url.URL{Path: "script.js"},
+	})
+	require.NoError(t, err)
+
+	err = out.client.PushMetric("testmetric", nil)
+	assert.True(t, os.IsTimeout(err))
+}
